/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package io.opentelemetry.exporter.otlp.profiles;

import java.util.List;
import javax.annotation.concurrent.Immutable;

/**
 * Describes the mapping of a binary in memory.
 *
 * @see "pprofextended.proto::Mapping"
 */
@Immutable
public interface MappingData {

  /** Address at which the binary (or DLL) is loaded into memory. */
  long getMemoryStart();

  /** The limit of the address range occupied by this mapping. */
  long getMemoryLimit();

  /** Offset in the binary that corresponds to the first mapped address. */
  long getFileOffset();

  /**
   * The object this entry is loaded from. This can be a filename on disk for the main binary and
   * shared libraries, or virtual abstraction like "[vdso]". Index into the string table.
   */
  long getFilenameIndex();

  /**
   * Uniquely identifies a particular program version with high probability. e.g., for binaries
   * generated by GNU tools, the contents of the .note.gnu.build-id field. Index into the string
   * table.
   */
  long getBuildIdIndex();

  /** Specifies the kind of build id. See BuildIdKind enum for more details */
  BuildIdKind getBuildIdKind();

  /** References to attributes in Profile.attribute_table. */
  List<Long> getAttributeIndices();

  boolean hasFunctions();

  boolean hasFilenames();

  boolean hasLineNumbers();

  boolean hasInlineFrames();
}
